@@ -60,6 +60,10 @@ def docs():
         "[33] ssap.scatter05box(df, parameter_x, parameter_y, title)\n"
         "[34] ssap.scatter06histlr(df, parameter_x, parameter_y, bins, title)\n"
         "[35] ssap.scatter07boxlr(df, parameter_x, parameter_y, title)\n"
+        "[36] ssap.scatter08lrci(df, parameter_x, parameter_y, title)\n"
+        "[37] ssap.scatter09lr6sigma(df, parameter_x, parameter_y, sigma, title)\n"
+        "[38] ssap.normaltest(targetlist)\n"
+
     )
     # explain details:
     # print(
@@ -104,7 +108,8 @@ def cmd():
         "[8] df2.sort_values(by=['xxx'],inplace=True) | 'sort values'\n"
         "[9] set(df) | 'remove duplicate for one parameter'\n"
         "[10] df['new column'] = df['existing column'] + 100 | 'add a new column' \n"
-        "[11] pip show (package name)\n"
+        "[11] pip show (package name) | 'show package details'\n"
+        "[12] data.loc[(data['para1'] == x) & (data['para-3']>xx)]\n"
     )
 
 
@@ -1570,8 +1575,28 @@ def scatter09lr6sigma(df, parameter_x, parameter_y, sigma, title):
     plt.title(title)
     plt.show()
 
-# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> [to be validated. update:12/28]
 
+# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> [to be validated. update:12/28]
+def normaltest(targetlist):
+    import numpy as np
+    from scipy import stats
+    import matplotlib.pyplot as plt
+    #     x = stats.norm.rvs(loc=0, scale=100, size=100) | standard normality sample
+
+    x = targetlist
+    stat, pval = stats.normaltest(x)
+
+    print(pval)
+    if pval < 0.05:
+        label = 'Probability Plot | p_val=' + str("{0:.3g}".format(pval)) + ' | Not follow normality.'
+    else:
+        label = 'Probability Plot | p_val=' + str("{0:.3g}".format(pval)) + ' | Follow Normality.'
+
+    plt.figure(figsize=(8, 5))
+    plt.grid(linestyle='-', lw=0.5)
+    stats.probplot(x, dist='norm', plot=plt)
+    plt.title(label)
+    plt.show()
 
 
 
